% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : acou_affich_form.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Dernire modification par H. Loevenbruck 29.10.02
% Contenu : Lecture + affichage du fichier  
%          contenant les formants.
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function acou_affich_form(nomfic,type)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 2
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : acou_affich_form(nomfic, typefic)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global NUM_FEN INDEX NB_LIG NB_COL SUPERPOSE ACOU_NOM_FIC ACOU_TYP_FIC ACOU_FECH CURSEUR
tps = [];
data = [];
val = [];

if strcmp(type,'ECH')
  % Lecture du fichier ECH isis
  [data,nbech,fech] = acou_lire_param(nomfic,'FRM1..5:I2;');

elseif strcmp(type,'ASC')
  % lecture du fichier ascii  6 colonnes : 1 pour le temps et les 5 autres pour les formants
  fpar = fopen(nomfic);
  if (fpar == -1)
    errordlg([' Fichier ',nomfic,' introuvable'],'Erreur','on');
    data = [];
    return
  end
  val = fscanf(fpar,'%f %f %f %f %f %f',6);
  while ~isempty(val)
    tps = [tps; val(1)];
    data = [data; val(2) val(3) val(4) val(5) val(6)];
    val = fscanf(fpar,'%f %f %f %f %f %f',6);
  end
  fclose(fpar);
else
   errordlg(' Ce type de fichier de formants est inconnu.', 'Erreur', 'on');
   return;
end

if ~isempty(data)
  if isempty(tps)
    ld = length(data);
    tps = 0 : 1/fech : (1/fech)*(ld-1);
  end
  if NUM_FEN == 0
    errordlg(' Veuillez ouvrir une fenetre principale','Erreur','on');
    return;
  end

  figure(NUM_FEN);
  % Affichage des formants sur le sonagramme
  spec = findobj(NUM_FEN,'Type','image');
  if ~isempty(spec)
    axe_spec = get(spec(1),'Parent');
    xlim = get(axe_spec,'Xlim');
    ylim = get(axe_spec,'Ylim');
    subplot(axe_spec);
    hold on;
    plot(tps,data(:,1),'+','Color',[0.9 0   0.9]); %sort of magenta
    plot(tps,data(:,2),'+','Color',[0   0.7   0.9]); %sort of cyan
    plot(tps,data(:,3),'+','Color',[0   0.9 0]);   %sort of green
    axis([xlim ylim]);
    hold off;
  else
   hsub = subplot(NB_LIG+1,NB_COL,INDEX);
   if SUPERPOSE
     hold on
   else 
     hold off
   end
   plot(tps,data(:,1),'+','Color',[0.9 0   0.9]); %sort of magenta
   hold on;
   plot(tps,data(:,2),'+','Color',[0   0.7   0.9]); %sort of cyan
   plot(tps,data(:,3),'+','Color',[0   0.9 0]);   %sort of green
   ylim = get(hsub,'Ylim');
   xlim = get(hsub,'Xlim');
   axis([xlim ylim(1) ACOU_FECH/2]);
   grid on;
   titre('FORMANTS');
   % On rcrit le titre de la fenetre
   if INDEX == 1
      titre_fen_princ((xlim(2)-xlim(1))/2, ylim(2)+(ylim(2)-ylim(1))/3, ['Fichier ',ACOU_NOM_FIC]);
   end

   % On rend actif le menu deroulant
   set(hsub,'Buttondownfcn','plot_menu');

   % On dsactive les anciens graphes
   % et active le courant
   active_graphe;

   %mise  jour des bornes du curseur
    if CURSEUR
        maj_curseur; 
    end


  end  
end
