% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : acou_calc_lpc.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 29.09.99
% Modifi par C.S. le 17/05/04 : couleur des graphes gre par variable
% globale (COULEUR_GRAPH)
%
% Contenu : Calcule la LPC du signal  un 
%           instant donn
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function acou_calc_lpc(pos_sb)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 1
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : acou_calc_lpc(instant)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global ACOU_SIG ACOU_FECH ACOU_ORD_LPC NUM_SYNC IND_SYNC COL_SYNC COULEUR_GRAPH


figNumber=watchon;

% Test si le fichier acoustique a t charg
if isempty(ACOU_SIG)
  errordlg(' Fichier acoustique non charg','Erreur','on');
  watchoff(figNumber);
  return;
end

% Rcupre une portion de signal centre sur le curseur
sig_lpc = acou_fen_signal(pos_sb);

if ~isempty(sig_lpc)
  
  ['lpc  t = ',num2str(pos_sb)];

  coef_lpc = lpc(sig_lpc,ACOU_ORD_LPC);   % Calcul des coeff. du filtre LPC
  
  gain = 1/(sum(abs(coef_lpc)));    % Calcul du gain du filtre LPC
  
  % Rponse frquentielle du filtre LPC
  [rep_lpc,freq] = freqz(gain,coef_lpc,512,ACOU_FECH);
  
  % Affichage
  figure(NUM_SYNC);
  subplot(1,COL_SYNC,IND_SYNC);
  plot(freq,20*log10(abs(rep_lpc)),'Color',COULEUR_GRAPH);
  grid on;
  buf = sprintf('LPC  t =%6.2f s',pos_sb);
% Attention ne pas changer cette couleur
% sinon la modification d'chelle marchera moins bien
% cf. modif_echelle.m
  title(buf,'Color','g');  %le titre est crit en green
  xlabel('Frquence Hz');
  ylabel('Amplitude dB');

  % Incrmente l'index des subplots
  if IND_SYNC == COL_SYNC
    IND_SYNC = 1;
  else
    IND_SYNC = IND_SYNC + 1;
  end
end

watchoff(figNumber);
