% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : acou_ouv.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 17.01.2000
% Modifi par CS le 11/09/00 :
%    fichiers EMA brut version Phil Hoole (15 colonnes)
% Modifi par LN et CS le 01/03/02 :
%    nom des fichiers acoustiques differents (*_001.wav)
% Modifi par LN le 04.03.02 :
% Dsormais, pour les donnes EMA, n'ouvre que 
% le fichier acoustique (et plus les donnes artic. associes)
% Modifi par CS le 18/03/04 :
%    initialise les variables de ZOOM
%
%
% Contenu : Ouverture du fichier acoustique spcifi.
%
% Si le fichier est au format EPG Kay (.nsp) :
% les donnes artic. et acoustiques sont 
% ds le meme fichier, donc traitement particulier.
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function acou_ouv(nomfic, typefic)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 2
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : ouvrir(nomfic, typefic)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global ACOU_SIG ACOU_TPS ACOU_NOM_FIC ACOU_TYP_FIC EMA_FECH EMA_SIG EMA_TPS EPG_SIG EPG_TPS ACOU_FECH
global ZOOM_PREC_DEB ZOOM_PREC_FIN

figNumber=watchon;

ACOU_SIG  = [];
ACOU_TPS = [];
long = length(nomfic);
nbech_acou = 0;
    

% ==========================================
% Pour compatibilit avec version prcdente
% de TRAP :
% Si le fichier est de type EMA
% ==========================================
    
if strcmp(typefic, 'EMA')
     ema_ouv_mat(nomfic);

     watchoff(figNumber);
     return;

% ===============================  
% Si le fichier est de type EPG
% ===============================
    
elseif strcmp(typefic, 'EPG')
     ACOU_TYP_FIC = 'EPG';    
     ACOU_NOM_FIC = nomfic;

    [EPG_SIG,ACOU_SIG,ACOU_TPS,EPG_TPS] = acou_ouv_epg(nomfic);
    ZOOM_PREC_DEB = 0;
    ZOOM_PREC_FIN = size(ACOU_TPS,2)/ACOU_FECH;

     watchoff(figNumber);
     return;

% ====================================  
% Si le fichier est de type ECH (ISIS)
% ====================================

elseif strcmp(typefic, 'ECH')
     ACOU_TYP_FIC = 'ECH';  

     ACOU_NOM_FIC = nomfic;

     [ACOU_SIG,ACOU_TPS] = acou_ouv_ech(nomfic);
    ZOOM_PREC_DEB = 0;
    ZOOM_PREC_FIN = size(ACOU_TPS,2)/ACOU_FECH;

     watchoff(figNumber);
     return;

% =======================================
% Si le fichier est de type .mat (MATLAB)
% =======================================

elseif strcmp(typefic, 'MAT')
     ACOU_TYP_FIC = 'MAT';  

     ACOU_NOM_FIC = nomfic;

     [ACOU_SIG,ACOU_TPS] = acou_ouv_bin(nomfic);
    ZOOM_PREC_DEB = 0;
    ZOOM_PREC_FIN = size(ACOU_TPS,2)/ACOU_FECH;

     watchoff(figNumber);
     return;

% ===============================  
% Si le fichier est de type WAV
% ===============================   
 
elseif strcmp(typefic, 'WAV')
    ACOU_TYP_FIC = 'WAV';  
    ACOU_NOM_FIC = nomfic;

    [ACOU_SIG,ACOU_TPS] = acou_ouv_wav(nomfic);
    ZOOM_PREC_DEB = 0;
    ZOOM_PREC_FIN = size(ACOU_TPS,2)/ACOU_FECH;

    watchoff(figNumber);
    return;
       
% =========================================  
% Si le fichier est de type binaire inconnu
% =========================================   

elseif strcmp(typefic, 'BIN')
     ACOU_TYP_FIC = 'BIN';  
     chaine_erreur = sprintf(' Attention !\n\n Ce format de fichier est inconnu.\n Le fichier sera considr comme un fichier binaire.\n\n');
     errordlg(chaine_erreur, 'Attention','on');
     ACOU_NOM_FIC = nomfic;

     [ACOU_SIG,ACOU_TPS] = acou_ouv_bin(nomfic);
    ZOOM_PREC_DEB = 0;
    ZOOM_PREC_FIN = size(ACOU_TPS,2)/ACOU_FECH;

% =========================================  
% Si l'utilisateur a entr un type inconnu
% =========================================   

else
  message = sprintf(' Type de fichier erron.    \n Choisir parmi :\n    - EMA\n    - EPG\n    - ECH\n    - MAT\n    - WAV\n    - BIN\n');
  errordlg(message, 'Erreur', 'on');
end

% On dfinit le zoom par defaut a partir de la totalit du signal
% acoustique


watchoff(figNumber);
