% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : acou_ouv_ech.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 17.01.2000
% Contenu : Ouverture d'un fichier isis
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function[signal,temps] =  acou_ouv_ech(nom)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 1
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : acou_ouv_ech(nom)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global ACOU_FECH

if ACOU_FECH == 0
  errordlg(' Veuillez spcifier la frquence d''chantillonnage !','Erreur','on');
  return;
end

%=================================
% Ouverture du fichier en lecture
%=================================
% Ouverture du fichier binaire avec le format : 
% IEEE floating point with little-endian byte ordering

fid = fopen(nom, 'rb','ieee-le');
if fid == -1   
     errordlg([' Fichier ', nom,' introuvable'], 'Rsultat', 'on');
     return;
end

%==============================================
% Recherche de la frquence d'chantillonnage 
%==============================================

% Se placer aprs en-tete de 120 octets en begin-of-file
fseek(fid, 120,'bof');
   
% Lecturex de 4 shorts contenant infos sur la frq. d'ch.
[signal,nb_ech] = fread(fid, 4, 'short'); 

if (signal(3) == -32000) & (signal(4) == 32149)
   fech = signal(2)*10^signal(1);
   if fech ~= ACOU_FECH
      ACOU_FECH = fech;
      message = sprintf(' La frquence d''chantillonnage est modifie  %d', ACOU_FECH);
      errordlg(message, 'Attention', 'on');
   end
end

%================================
% Lecture des donnes du fichier
%================================

% Se placer aprs en-tete de 128 octets en begin-of-file
fseek(fid, 128,'bof');  

% lecture des ech sur 2 octets
[signal,nb_ech] = fread(fid, inf, 'short'); 

%================================
% Calcul des donnes temporelles
%================================

temps = linspace(0,(nb_ech-1)/ACOU_FECH,nb_ech);

%=====================
% Fermeture du fichier
%=====================

fclose(fid);
