% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : acou_ouv_ema.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date 21.06.99
% Modifi par H. Loevenbruck 28.01.2000
% Contenu : Lecture d'un fichier acoustique 
%           au format EMA.
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function[As,counts,ts] = acou_ouv_ema(nomfich)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 1
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : acou_ouv_ema(nomfic)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global ACOU_FECH

if ACOU_FECH == 0
  errordlg(' Veuillez spcifier la frquence d''chantillonnage !','Erreur','on');
  return;
end


%=================================
% Ouverture du fichier en lecture
%=================================

% Ouverture du fichier binaire avec le format : 
% IEEE floating point with little-endian byte ordering

fs = fopen(nomfich,'r','ieee-le');
if fs == -1   
  errordlg([' Fichier ',nomfich,' introuvable'],'Rsultat','on');
  return;
else
%  errordlg([' Ouverture du fichier ',nomfich],'Rsultat','off');  
end

%================================
% Lecture des donnes du fichier
%================================

% Lecture du fichier binaire par paquets de : unsigned integer, 16 bits
[As1,counts] = fread(fs,'ushort');

% Suppression de l'offset sur les donnes acoustiques :
As = As1 - 2048;

%================================
% Calcul des donnes temporelles
%================================

ts=linspace(0,(counts-1)/ACOU_FECH,counts);

%=====================
% Fermeture du fichier
%=====================

fclose(fs);
