% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : affich_coord_curseur.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 24.09.99
% Contenu : Affichage des coordonnes courantes
%           du curseur, en haut de chaque subplot,
%           pour chacun des signaux contenus ds 
%           le subplot.
%
% Les coordonnees x, y de chaque signal s'affichent
% dans la couleur du signal.
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function affich_coord_curseur(pos_sb)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 1
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : affich_coord_curseur(instant)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global NUM_FEN NB_LIG NB_COL INDEX

if NUM_FEN == 0
  errordlg(' Veuillez ouvrir une fenetre principale','Erreur','on');
  return;
end

figure(NUM_FEN);

% Recherche le nombre d'axes prsents dans la fenetre
%=====================================================
tous_axes = findobj(gcf,'Type','axes');

for ind_axes = 1 : length(tous_axes)

  % Efface les anciennes valeurs des coordonnes 
  %=============================================
  % Cherche tous les textes affichs juste au-dessus du subplot :
  texte = findobj(tous_axes(ind_axes),'Type','text', 'VerticalAlignment', 'baseline', 'HorizontalAlignment', 'left');
 
  for i = 1 : length (texte)
     couleur_text = get(texte(i),'color');
     test = (couleur_text == [0 1 0]); %si le texte est vert (titre)
     if (test(1) ~= 1 | test(2) ~= 1 | test(3) ~= 1) % Si ce n'est pas le titre du subplot
        delete(texte(i));
     end
  end

  % Affiche les nouvelles coordonnes
  %==================================

  % Recherche de tous les signaux et tiquettes contenus ds l'axe courant

  gr_lines = findobj(tous_axes(ind_axes),'Type','line');

  if ~isempty(gr_lines)
    subplot(tous_axes(ind_axes));
    [gr_lines_tries,ind_gr_lines_tries] = sort(gr_lines); 

    nb_signaux = 0;

    for ind_gr = 1 : length(gr_lines)
       val_x = get(gr_lines(ind_gr_lines_tries(ind_gr)),'Xdata');

       % On ne s'intresse qu'aux signaux et on vacue les tiquettes
       if (length(val_x) > 2) 
          nb_signaux = nb_signaux +1;
          couleur(nb_signaux, : ) = get(gr_lines(ind_gr_lines_tries(ind_gr)),'color');
          val_y = get(gr_lines(ind_gr_lines_tries(ind_gr)),'Ydata');
 
          % Recherche l'indice dans val_x de la valeur du curseur
          [m,ind] = min(abs(val_x - pos_sb));
          curs_x(nb_signaux) = val_x(ind);
          curs_y(nb_signaux) = val_y(ind);

          % Recherche les limites du graph pour afficher les coord.
          ylim = get(tous_axes(ind_axes),'Ylim');
          xlim = get(tous_axes(ind_axes),'Xlim');
        
       end   
    end

    for i = 1 : nb_signaux
       if (i == 1)
          buf = sprintf('x=%3.2f  y=%3.2f',curs_x(i), curs_y(i));
          text(xlim(1) + (xlim(2)-xlim(1))/3, ylim(2), buf, 'VerticalAlignment', 'baseline', 'HorizontalAlignment', 'left', 'Color', couleur(i, : )); 
       else
          buf = sprintf('%3.2f', curs_y(i) );
          M = xlim(1) + (xlim(2)-xlim(1))/3;
          text(M + i*(xlim(2)-M)/(nb_signaux+1), ylim(2), buf, 'VerticalAlignment', 'baseline', 'HorizontalAlignment', 'left', 'Color', couleur(i, : )); 
       end
    end
  end
end


% On s'assure que le gca n'a pas chang
subplot(NB_LIG+1,NB_COL,INDEX);


