% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : ema_XY_3D.m
% Source : Matlab
% Auteur : M.-C. Leroy & P. Pinoit
% Adapt par D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 29.09.99
% Modifi par CS le 11/09/00 :
%    lecture des fichiers EMA brut version Phil Hoole (15 colonnes) : X1..X5 Y1..Y5 T1..T5
% Dernire modification : HL : 04.03.02
% Modifi par CS le 30/11/02 :
%    lecture des fichiers EMA 10 canaux (30 colonnes) : X1..X10 Y1..Y10 T1..T10
% Modifi par CS le 17/06/04 :
%    possibilit de lire les donnes en millimtre
% Modifi par CS le 07/01/16 :
%       Passage en 3D et conversion en cm
% Modifi par CS le 01/09/16 :
%       Passage  16 canaux
% Contenu : convertit les donnes articulatoires
%           squentielles (vecteur colonne), 
%           issues du fichier EMA, en une matrice
%           de coord x et y pour chaque bobine
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [bx,by,bz] = ema_XY_3D(data)
global EMA_ECHELLE

if nargin < 1
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : ema_XY(data)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

% On cherche combien il y a de canaux utiliss
nb_canaux = size(data,2)/3;

% On spare les donnes en X, Y, Z
for i=1:nb_canaux
    bx(:,i) = data(:,i);
    by(:,i) = data(:,i + nb_canaux);
    bz(:,i) = data(:,i + 2*nb_canaux);
end

% on initialise les canaux non utiliss si necessaire
% if ~isequal(nb_canaux,10)
%     for i=nb_canaux + 1:10
%         bx(:,i) = 0;
%         by(:,i) = 0;
%         bz(:,i) = 0;
%     end
% end

% Passage  16 canaux
if ~isequal(nb_canaux,16)
    for i=nb_canaux + 1:16
        bx(:,i) = 0;
        by(:,i) = 0;
        bz(:,i) = 0;
    end
end

% Test pour savoir si les donnes sont a exprimer en centimtre
if EMA_ECHELLE == 0.1
    %On passe tout en cm
    bx = bx /10;
    by = by /10;
    bz = bz /10;
end
