% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : ema_traitement_3D.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 29.09.99, 04.03.2002
%
% Modifi par CS le 18.03.03 : 
% Passage  10 canaux 
%
% Modifi par CS le 07/01/16 :
%       Passage en 3D, fichier issu de l'algorithme de Mark Tiede
%       Head-Correction
% Modifi par CS le 01/09/16 :
%       Passage  16 canaux
%
% Contenu : Ouverture  et traitement des 
%          fichiers EMA
% REMARQUE : le filtrage Passe Bas est effectu par defaut
%            pour le supprimer il faut mettre la valeur CHEBY_FREQ_COUP  0
%            avant de dessiner les trajectoires    
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [res] = ema_traitement_3D

global EMA_FECH EMA_SIG EMA_TPS EMA_FLAG
global EMA_X1 EMA_X2 EMA_X3 EMA_X4 EMA_X5 EMA_Y1 EMA_Y2 EMA_Y3 EMA_Y4 EMA_Y5 
global EMA_X6 EMA_X7 EMA_X8 EMA_X9 EMA_X10 EMA_Y6 EMA_Y7 EMA_Y8 EMA_Y9 EMA_Y10 
global EMA_Z1 EMA_Z2 EMA_Z3 EMA_Z4 EMA_Z5 EMA_Z6 EMA_Z7 EMA_Z8 EMA_Z9 EMA_Z10 
global EMA_X11 EMA_X12 EMA_X13 EMA_X14 EMA_X15 EMA_X16 EMA_Y11 EMA_Y12 EMA_Y13 EMA_Y14 EMA_Y15 EMA_Y16
global EMA_Z11 EMA_Z12 EMA_Z13 EMA_Z14 EMA_Z15 EMA_Z16
global CHEBY_FREQ_COUP


% Test du type du fichier
if ~isempty(EMA_TPS)
    [bx,by,bz] = ema_XY_3D(EMA_SIG);
    
    % traitement des NaN si prsent
    ind_nan_bx = find(isnan(bx));
    if ~isempty(ind_nan_bx)
        bx(ind_nan_bx)=0;
        by(ind_nan_bx)=0;
        bz(ind_nan_bx)=0;
        %         msgbox('Attention donnees EMA manquantes (NaN)','Warning','warn');
    end
    
    EMA_X1 = bx(:,1)';
    EMA_X2 = bx(:,2)';
    EMA_X3 = bx(:,3)';
    EMA_X4 = bx(:,4)';
    EMA_X5 = bx(:,5)';
    EMA_X6 = bx(:,6)';
    EMA_X7 = bx(:,7)';
    EMA_X8 = bx(:,8)';
    EMA_X9 = bx(:,9)';
    EMA_X10 = bx(:,10)';
    % ajout 16 canaux
    EMA_X11 = bx(:,11)';
    EMA_X12 = bx(:,12)';
    EMA_X13 = bx(:,13)';
    EMA_X14 = bx(:,14)';
    EMA_X15 = bx(:,15)';
    EMA_X16 = bx(:,16)';
    
    % on cherche les zro dans les variables
    x1_iszero = find(EMA_X1 == 0);
    x2_iszero = find(EMA_X2 == 0);
    x3_iszero = find(EMA_X3 == 0);
    x4_iszero = find(EMA_X4 == 0);
    x5_iszero = find(EMA_X5 == 0);
    x6_iszero = find(EMA_X6 == 0);
    x7_iszero = find(EMA_X7 == 0);
    x8_iszero = find(EMA_X8 == 0);
    x9_iszero = find(EMA_X9 == 0);
    x10_iszero = find(EMA_X10 == 0);
    x11_iszero = find(EMA_X11 == 0);
    x12_iszero = find(EMA_X12 == 0);
    x13_iszero = find(EMA_X13 == 0);
    x14_iszero = find(EMA_X14 == 0);
    x15_iszero = find(EMA_X15 == 0);
    x16_iszero = find(EMA_X16 == 0);

    EMA_Y1 = by(:,1)';
    EMA_Y2 = by(:,2)';
    EMA_Y3 = by(:,3)';
    EMA_Y4 = by(:,4)';
    EMA_Y5 = by(:,5)';
    EMA_Y6 = by(:,6)';
    EMA_Y7 = by(:,7)';
    EMA_Y8 = by(:,8)';
    EMA_Y9 = by(:,9)';
    EMA_Y10 = by(:,10)';
    % ajout 16 canaux
    EMA_Y11 = by(:,11)';
    EMA_Y12 = by(:,12)';
    EMA_Y13 = by(:,13)';
    EMA_Y14 = by(:,14)';
    EMA_Y15 = by(:,15)';
    EMA_Y16 = by(:,16)';

    EMA_Z1 = bz(:,1)';
    EMA_Z2 = bz(:,2)';
    EMA_Z3 = bz(:,3)';
    EMA_Z4 = bz(:,4)';
    EMA_Z5 = bz(:,5)';
    EMA_Z6 = bz(:,6)';
    EMA_Z7 = bz(:,7)';
    EMA_Z8 = bz(:,8)';
    EMA_Z9 = bz(:,9)';
    EMA_Z10 = bz(:,10)';
    % ajout 16 canaux
    EMA_Z11 = bz(:,11)';
    EMA_Z12 = bz(:,12)';
    EMA_Z13 = bz(:,13)';
    EMA_Z14 = bz(:,14)';
    EMA_Z15 = bz(:,15)';
    EMA_Z16 = bz(:,16)';
    
    % Filtrage des donnes si CHEBY_FREQ_COUP ~= 0
    % CS : 15 canaux
    if CHEBY_FREQ_COUP ~= 0
         disp('Attention donnes EMA filtres par Passe Bas de Chebyshev')
        [EMA_X1,EMA_X2,EMA_X3,EMA_X4,EMA_X5] = ema_filtre(EMA_X1,EMA_X2,EMA_X3,EMA_X4,EMA_X5,EMA_FECH);
        [EMA_Y1,EMA_Y2,EMA_Y3,EMA_Y4,EMA_Y5] = ema_filtre(EMA_Y1,EMA_Y2,EMA_Y3,EMA_Y4,EMA_Y5,EMA_FECH);
        [EMA_Z1,EMA_Z2,EMA_Z3,EMA_Z4,EMA_Z5] = ema_filtre(EMA_Z1,EMA_Z2,EMA_Z3,EMA_Z4,EMA_Z5,EMA_FECH);
        [EMA_X6,EMA_X7,EMA_X8,EMA_X9,EMA_X10] = ema_filtre(EMA_X6,EMA_X7,EMA_X8,EMA_X9,EMA_X10,EMA_FECH);
        [EMA_Y6,EMA_Y7,EMA_Y8,EMA_Y9,EMA_Y10] = ema_filtre(EMA_Y6,EMA_Y7,EMA_Y8,EMA_Y9,EMA_Y10,EMA_FECH);
      [EMA_Z6,EMA_Z7,EMA_Z8,EMA_Z9,EMA_Z10] = ema_filtre(EMA_Z6,EMA_Z7,EMA_Z8,EMA_Z9,EMA_Z10,EMA_FECH);
      % ajout 16 canaux
      [EMA_X11,EMA_X12,EMA_X13,EMA_X14,EMA_X15] = ema_filtre(EMA_X11,EMA_X12,EMA_X13,EMA_X14,EMA_X15,EMA_FECH);
      [EMA_Y11,EMA_Y12,EMA_Y13,EMA_Y14,EMA_Y15] = ema_filtre(EMA_Y11,EMA_Y12,EMA_Y13,EMA_Y14,EMA_Y15,EMA_FECH);
      [EMA_Z11,EMA_Z12,EMA_Z13,EMA_Z14,EMA_Z15] = ema_filtre(EMA_Z11,EMA_Z12,EMA_Z13,EMA_Z14,EMA_Z15,EMA_FECH);
  end
  % REM : 16e canal non filtr !!!!
  % on remet des NaN
      EMA_X1(x1_iszero)=NaN;
      EMA_X2(x2_iszero)=NaN;
      EMA_X3(x3_iszero)=NaN;
      EMA_X4(x4_iszero)=NaN;
      EMA_X5(x5_iszero)=NaN;
      EMA_X6(x6_iszero)=NaN;
      EMA_X7(x7_iszero)=NaN;
      EMA_X8(x8_iszero)=NaN;
      EMA_X9(x9_iszero)=NaN;
      EMA_X10(x10_iszero)=NaN;
      EMA_X11(x11_iszero)=NaN;
      EMA_X12(x12_iszero)=NaN;
      EMA_X13(x13_iszero)=NaN;
      EMA_X14(x14_iszero)=NaN;
      EMA_X15(x15_iszero)=NaN;
      % Autorise le calcul des vitesses
      res = 1;
      EMA_FLAG = 1;
  
else
  res = 0;
  errordlg(' Fichier EMA non ouvert, non conforme ou vide','Erreur','on');
end
