% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : enr_minmaxppz.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 01.04.2000
% Contenu : Enregistre les reprages min, max, etc.
%           dans un fichier
% Modifi par CS le 07/01/16 :
%       suppression du tri des fenetres, non compatible Matlab 2015 
% Modifi par CS le 14/02/17 :
%       ajout du titre des fentres pour savoir o se situe les vnements
%       suppression du tri par tiquettes
%
% Modifi par CS le 15/02/18 :
%       ajout du mode reperage 20% du max 20pc, uniquement
%       sur signaux EMA
%
% Attention ne marche que si les repres portent
% les couleurs suivantes (dfinies ds trap.m):
% tiquette min : COULEUR_MIN
% tiquette max : COULEUR_MAX
% tiquette ppz : COULEUR_ZERO
% croix moy :     COULEUR_MOY
% tiquette 20% : COULEUR_20PC
% et si le titre est bien crit en vert
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function enr_minmaxppz(nomfic)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 1
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : enr_minmaxppz(nomfic)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global NUM_FEN ACOU_NOM_FIC ACOU_TYP_FIC COULEUR_MIN COULEUR_MAX COULEUR_ZERO COULEUR_MOY COULEUR_20PC NIV_ETIQ

% initialisations
%================
clear htext
pos_min = [];
pos_max = [];
pos_ppz = [];
pos_moydeb = [];
pos_moymid = [];
pos_moyfin = [];
pos_20pc = [];
val_moymid = [];
tmp = [];
titre_fen = [];
ind_axe_min = 1;
ind_axe_max = 1;
ind_axe_ppz = 1;
ind_axe_moy = 1;
ind_axe_20pc = 1;

% Ouverture du fichier en criture
%=================================
fid = fopen(nomfic,'w');

if fid == -1 
  errordlg(' Impossible de crer un fichier de repres min, max ou ppz ! ','Erreur','on');
  return;
end

% Cherche les min, max, ppz et moy dans la fenetre courante 
%==========================================================
if NUM_FEN == 0
  errordlg(' Veuillez ouvrir une fenetre principale','Erreur','on');
  return;
end

figure(NUM_FEN)

%====================================================
% Recherche du nombre d'axes (ou subplots) prsents 
% dans la fenetre.
% Et triage par ordre de disposition  l'cran. 
%====================================================
tous_axes = findobj(gcf,'Type','axes');
%[axes_tries,ind_axes_tries] = sort(tous_axes); 

for ind_axes = 1 : length(tous_axes)
    
  % Recherche les tiquettes de type min
  %-------------------------------------
  %%%  hmin = findobj(tous_axes(ind_axes_tries(ind_axes)),'Type','line','Color',COULEUR_MIN); %Etiq min (bleue)
  hmin = findobj(tous_axes(ind_axes),'Type','line','Color',COULEUR_MIN); %Etiq min (bleue)
  if ~isempty(hmin)
    if ~exist('htext')
      % Recherche le titre du graphe
%       htext = findobj(tous_axes(ind_axes_tries(ind_axes)),'Type','text','Color',[0 1 0]); %titre en vert
      htext = findobj(tous_axes(ind_axes),'Type','text','Color',[0 1 0]); %titre en vert
      titre = get(htext,'String');

      fprintf(fid,'TRAP : Fichier de repres min, max, ppz ou moy\n');
      fprintf(fid,'signal : \t%s \n', ACOU_NOM_FIC);
      fprintf(fid,'comment : cree le \t%s\n', date);
    else
      htext = findobj(tous_axes(ind_axes),'Type','text','Color',[0 1 0]); %titre en vert
      titre = get(htext,'String');
    end

    for n = 1 : length(hmin)
      tmp = get(hmin(n),'Xdata');
      pos_min = [pos_min, tmp(1)];
      % Ajout CS
%       titre_fen_min = [titre_fen_min; titre];
       titre_fen(ind_axe_min).titre_min =  titre;
       ind_axe_min = ind_axe_min + 1;
      end
  end
  
  % Recherche les tiquettes de type max
  %-------------------------------------
 %%% hmax = findobj(tous_axes(ind_axes_tries(ind_axes)),'Type','line','Color',COULEUR_MAX); %Etiq max (orange)
  hmax = findobj(tous_axes(ind_axes),'Type','line','Color',COULEUR_MAX); %Etiq max (orange)
  if ~isempty(hmax)
    if ~exist('htext')
      % Recherche le titre du graphe
%       htext = findobj(tous_axes(ind_axes_tries(ind_axes)),'Type','text','Color',[0 1 0]); %titre en vert
       htext = findobj(tous_axes(ind_axes),'Type','text','Color',[0 1 0]); %titre en vert
      titre = get(htext,'String');

      fprintf(fid,'TRAP : Fichier de repres min, max, ppz ou moy\n');
      fprintf(fid,'type : \t%s\n', ACOU_TYP_FIC);
      fprintf(fid,'comment : cree le \t%s\n', date);
    else
      htext = findobj(tous_axes(ind_axes),'Type','text','Color',[0 1 0]); %titre en vert
      titre = get(htext,'String');
    end

    for n = 1 : length(hmax)
      tmp = get(hmax(n),'Xdata');
      pos_max = [pos_max, tmp(1)];
      % Ajout CS
       titre_fen(ind_axe_max).titre_max =  titre;
       ind_axe_max = ind_axe_max + 1;
%       titre_fen_max = [titre_fen_max; titre];
    end
  end 

  % Recherche les tiquettes de type 20pc
  %-------------------------------------
 %%% hmax = findobj(tous_axes(ind_axes_tries(ind_axes)),'Type','line','Color',COULEUR_MAX); %Etiq max (orange)
  h20pc = findobj(tous_axes(ind_axes),'Type','line','Color',COULEUR_20PC); %Etiq max (orange)
  if ~isempty(h20pc)
    if ~exist('htext')
      % Recherche le titre du graphe
%       htext = findobj(tous_axes(ind_axes_tries(ind_axes)),'Type','text','Color',[0 1 0]); %titre en vert
       htext = findobj(tous_axes(ind_axes),'Type','text','Color',[0 1 0]); %titre en vert
      titre = get(htext,'String');

      fprintf(fid,'TRAP : Fichier de repres min, max, ppz ou moy\n');
      fprintf(fid,'type : \t%s\n', ACOU_TYP_FIC);
      fprintf(fid,'comment : cree le \t%s\n', date);
    else
      htext = findobj(tous_axes(ind_axes),'Type','text','Color',[0 1 0]); %titre en vert
      titre = get(htext,'String');
    end

    for n = 1 : length(h20pc)
      tmp = get(h20pc(n),'Xdata');
      pos_20pc = [pos_20pc, tmp(1)];
      % Ajout CS
       titre_fen(ind_axe_20pc).titre_20pc =  titre;
       ind_axe_20pc = ind_axe_20pc + 1;
%       titre_fen_max = [titre_fen_max; titre];
    end
  end 

  % Recherche les tiquettes de type ppz
  %-------------------------------------
%   hppz = findobj(tous_axes(ind_axes_tries(ind_axes)),'Type','line','Color',COULEUR_ZERO); %Etiq ppz (green)
  hppz = findobj(tous_axes(ind_axes),'Type','line','Color',COULEUR_ZERO); %Etiq ppz (green)
  if ~isempty(hppz)
    if ~exist('htext')
      % Recherche le titre du graphe
%       htext = findobj(tous_axes(ind_axes_tries(ind_axes)),'Type','text','Color',[0 1 0]); %titre en vert
      htext = findobj(tous_axes(ind_axes),'Type','text','Color',[0 1 0]); %titre en vert
      titre = get(htext,'String');

      fprintf(fid,'TRAP : Fichier de repres min, max, ppz ou moy\n');
      fprintf(fid,'signal : \t%s \n', ACOU_NOM_FIC);
      fprintf(fid,'comment : cree le \t%s\n', date);
    else
      htext = findobj(tous_axes(ind_axes),'Type','text','Color',[0 1 0]); %titre en vert
      titre = get(htext,'String');
    end

    for n = 1 : length(hppz)
      tmp = get(hppz(n),'Xdata');
      pos_ppz = [pos_ppz, tmp(1)];
      % Ajout CS
       titre_fen(ind_axe_ppz).titre_ppz =  titre;
       ind_axe_ppz = ind_axe_ppz + 1;
    end
  end

  % Recherche les tiquettes et les repres-croix de type moy
  %----------------------------------------------------------

  % Etiquette de dbut:
%   hmoydeb = findobj(tous_axes(ind_axes_tries(ind_axes)),'Type','line','Color',COULEUR_MOY, 'LineStyle', '-'); 
  hmoydeb = findobj(tous_axes(ind_axes),'Type','line','Color',COULEUR_MOY, 'LineStyle', '-'); 
  if ~isempty(hmoydeb)
    if ~exist('htext')
      % Recherche le titre du graphe
%       htext = findobj(tous_axes(ind_axes_tries(ind_axes)),'Type','text','Color',[0 1 0]); %titre en vert
      htext = findobj(tous_axes(ind_axes),'Type','text','Color',[0 1 0]); %titre en vert
      titre = get(htext,'String');

      fprintf(fid,'TRAP : Fichier de repres min, max, ppz ou moy\n');
      fprintf(fid,'signal : %s \n', ACOU_NOM_FIC);
      fprintf(fid,'comment : cree le %s\n', date);
    else
      htext = findobj(tous_axes(ind_axes),'Type','text','Color',[0 1 0]); %titre en vert
      titre = get(htext,'String');
    end

    for n = 1 : length(hmoydeb)
      tmp = get(hmoydeb(n),'Xdata');
      pos_moydeb = [pos_moydeb, tmp(1)];
      % Ajout CS
       titre_fen(ind_axe_moy).titre_moy =  titre;
       ind_axe_moy = ind_axe_moy + 1;
%       titre_fen_moy = [titre_fen_moy, titre];
    end

    % Etiquette de fin:
%     hmoyfin = findobj(tous_axes(ind_axes_tries(ind_axes)),'Type','line','Color',COULEUR_MOY, 'LineStyle', '--'); 
     hmoyfin = findobj(tous_axes(ind_axes),'Type','line','Color',COULEUR_MOY, 'LineStyle', '--'); 
    for n=1 : length(hmoyfin)
      tmp = get(hmoyfin(n),'Xdata');
      pos_moyfin = [pos_moyfin, tmp(1)];
    end
 
    % repre de milieu:
%     hmoymid = findobj(tous_axes(ind_axes_tries(ind_axes)),'Type','line','Color',COULEUR_MOY, 'Marker', '+');
     hmoymid = findobj(tous_axes(ind_axes),'Type','line','Color',COULEUR_MOY, 'Marker', '+');
    for n=1 : length(hmoymid)
       tmpx = get(hmoymid(n),'Xdata');      
       tmpy = get(hmoymid(n),'Ydata');      
      pos_moymid = [pos_moymid, tmpx];
      val_moymid = [val_moymid, tmpy];
    end
  end 

end

% Pour les Etiquettes min
%========================
% CS
% [y_min,sort_ind_min] = sort(pos_min); % trie les valeurs temporelles
% for i = sort_ind_min  % pour tous les indices tris
for i = 1 : size(pos_min,2)  % pour tous les indices tris
    [buf_y] = calc_coord_etiq(pos_min(i));
    %    [buf_y, buf_titre] = calc_coord_etiq(pos_min(i));
    if ~isempty(buf_y)
        posy(i,:) = buf_y;
    end
    % supprime les lments vides des titres
    empty_elem_min = arrayfun(@(titre_fen) isempty(titre_fen.titre_min),titre_fen);
    titre_min = char(titre_fen(~empty_elem_min).titre_min);
    % imprime le nom de la fenetre concerne
    fprintf(fid,'%f\t%s\t%s', pos_min(i), 'min', deblank(titre_min(i,:)));
    
    % imprime les valeurs sur l'axe des y ( part les formants)
    for j = 1:size(posy,2)
        fprintf(fid,'\t%f',posy(i,j) );
    end
    fprintf(fid,'\n');
end

% Pour les Etiquettes max
%========================
% [y_max,sort_ind_max] = sort(pos_max); % trie les valeurs temporelles
% for i = sort_ind_max  % pour tous les indices tris
%    fprintf(fid,'%f\t%i\t%s', pos_max(i), NIV_ETIQ+2, 'max' );
for i = 1 : size(pos_max,2)  % pour tous les indices tris
   [buf_y] = calc_coord_etiq(pos_max(i));
   if ~isempty(buf_y)
       posy(i,:) = buf_y;
   end
   
    % supprime les lments vides des titres
    empty_elem_max = arrayfun(@(titre_fen) isempty(titre_fen.titre_max),titre_fen);
    titre_max = char(titre_fen(~empty_elem_max).titre_max);
    
    % imprime le nom de la fenetre concerne
    fprintf(fid,'%f\t%s\t%s', pos_max(i), 'max', deblank(titre_max(i,:)));

   % imprime les valeurs sur l'axe des y ( part les formants)
   for j = 1:size(posy,2)
      fprintf(fid,'\t%f',posy(i,j) );
   end
   fprintf(fid,'\n');
end

% Pour les Etiquettes 20pc
%========================
for i = 1 : size(pos_20pc, 2)  % pour tous les indices tris
   [buf_y] = calc_coord_etiq(pos_20pc(i));
   if ~isempty(buf_y)
       posy(i,:) = buf_y;
   end
   
    % supprime les lments vides des titres
    empty_elem_20pc = arrayfun(@(titre_fen) isempty(titre_fen.titre_pos_20pc),titre_fen);
    titre_20pc = char(titre_fen(~empty_elem_20pc).titre_20pc);
    
    % imprime le nom de la fenetre concerne
    fprintf(fid,'%f\t%s\t%s', pos_20pc(i), '20%max', deblank(titre_20pc(i,:)));

   % imprime les valeurs sur l'axe des y ( part les formants)
   for j = 1:size(posy,2)
      fprintf(fid,'\t%f',posy(i,j) );
   end
   fprintf(fid,'\n');
end

% Pour les Etiquettes ppz
%========================   
% [y_ppz,sort_ind_ppz] = sort(pos_ppz); % trie les valeurs temporelles
% for i = sort_ind_ppz  % pour tous les indices tris
%    fprintf(fid,'%f\t%i\t%s', pos_ppz(i), NIV_ETIQ+3, 'ppz' );
for i = 1 : size(pos_ppz,2)  % pour tous les indices tris
   [buf_y] = calc_coord_etiq(pos_ppz(i));
%    fprintf(fid,'%f\t%s\t%s', pos_ppz(i), 'max', deblank(titre_fen(i).titre_ppz));
   if ~isempty(buf_y)
       posy(i,:) = buf_y;
   end
    
    % supprime les lments vides des titres
    empty_elem_ppz = arrayfun(@(titre_fen) isempty(titre_fen.titre_ppz),titre_fen);
    titre_ppz = char(titre_fen(~empty_elem_ppz).titre_ppz);
    % imprime le nom de la fenetre concerne
    fprintf(fid,'%f\t%s\t%s', pos_ppz(i), 'ppz', deblank(titre_ppz(i,:)));

   % Affiche les valeurs sur l'axe des y ( part les formants)
   for j = 1:size(posy,2)
      fprintf(fid,'\t%f',posy(i,j) );
   end
   fprintf(fid,'\n');
end

% Pour les Etiquettes moy
%========================   
[y_moydeb,sort_ind_moydeb] = sort(pos_moydeb); % trie les valeurs temporelles
[y_moyfin,sort_ind_moyfin] = sort(pos_moyfin);
[y_moymid,sort_ind_moymid] = sort(pos_moymid);
for i = 1 : length(pos_moymid)
   fprintf(fid,'%f\t%f\t%s\t%s\t%f\n', pos_moydeb(sort_ind_moydeb(i)), pos_moyfin(sort_ind_moyfin(i)), 'moy', deblank(titre_fen(i).titre_moy), val_moymid(sort_ind_moymid(i)) );
end

fclose(fid);

