% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : enr_tempo.m
% Source : Matlab
% Auteur : Loevenbruck 
% Date : 22.07.99
% Contenu : Enregistre l'extrait de signal temporel
%           affich ds le subplot courant.
%
%           Trois formats d'enregistrements possibles :
%           - Format binaire ISIS .ech 
%             (avec en-tete contenant Fe)
%           - Format binaire Matlab .mat
%           - Format ASCII
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function enr_tempo(nomfic, type, fe)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 3
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : enr_tempo(nomfic, type, Fe))');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global NUM_FEN

if NUM_FEN == 0
  errordlg(' Veuillez ouvrir une fenetre principale','Erreur','on');
  return;
end

figure(NUM_FEN);
nb_signaux = 0;

%============================================
% Recherche de tous les signaux et tiquettes 
% contenus ds l'axe courant 
%============================================

gr_lines= findobj(gca,'Type','line');

if size(gr_lines,1) == 0
  errordlg(' Impossible d''enregistrer : ce signal n''est pas temporel !','Erreur','on');
  return;
else
   for ind_gr = 1 : length(gr_lines)
       donnees_tempo = get(gr_lines(ind_gr), 'xdata');

       %=============================================================
       % On ne s'intresse qu'aux signaux et on vacue les tiquettes
       %=============================================================

       if (length(donnees_tempo) > 2) 
           nb_signaux = nb_signaux + 1
           donnees_temporelles = donnees_tempo; % ne pas supprimer
           sig = get(gr_lines(ind_gr), 'ydata')';
       end
   end

   %============================================
   % Pas d'enregistrement possible si plusieurs 
   % graphes sont superposs ds le meme subplot
   %============================================
   if nb_signaux > 1
       errordlg(' Impossible d''enregistrer le signal : des graphes sont superposs !','Erreur','on');
       return;
   %============================================
   % Un seul graphe : on vrifie la frquence
   % d'chantillonnage et on enregistre le signal
   %============================================
   else
       BorneSupX = donnees_temporelles(length(donnees_temporelles));
       FrequenceEch = (length(donnees_temporelles) -1)/BorneSupX

       if (round(FrequenceEch) ~= fe)
           message = sprintf('La Frquence d''chantillonnage est %d et non pas %d !', round(FrequenceEch), fe);
           errordlg(message,'Attention','on');
           fe = round(FrequenceEch);
       end

       %================================
       % Enregistrement au format ISIS
       %================================
       if strcmp(type, 'ECH')
           acou_conversion_ech(nomfic, fe, sig);

       %================================
       % Enregistrement au format Matlab
       %================================
       elseif strcmp(type, 'MAT')
           nomfic = nomfic(1:length(nomfic-4))
           eval(['save ' nomfic ' sig']);

       %================================
       % Enregistrement au format ASCII
       %================================
       elseif strcmp(type, 'ASC')
            enr_ascii(nomfic, fe, sig);
       else
            errordlg(' Le type du fichier d''enregistrement est erron !','Erreur', 'on');
       end
   end
end
