% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : epg_ouv_elec.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 26.03.02
% Contenu : Ouverture et lecture du fichier
%           .usr (EPG).
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function epg_ouv_elec

global EPG_NB_ELEC EPG_POS_ELEC EPG_NOM_LOC EPG_REGIONS EPG_CHANNEL EPG_NOM_REG

%initialisation
elec = [];

%=================================
% Ouverture du fichier en lecture
%=================================
nomfic = [EPG_NOM_LOC,'.usr'];
fid = fopen(nomfic,'r','l');
if fid == -1   
  errordlg([' Fichier ',nomfic,' introuvable'],'Rsultat','on');
else
  % On ne lit pas les 2 premieres lignes
  ligne = fgetl(fid);
  ligne = fgetl(fid);

  % Pour les 96 lignes suivantes, qui correspondent aux 96 electrodes, 
  % On lit les 4 premiers chiffres, 
  % qui fournissent la correspondance entre 
  % chaque electrode(Elect) et sa voie (Channel),
  % ainsi que la position (Row  Col) de l'lectrode sur le palais.
  % Puis on lit les 18 rgions (TG1..18).
  for i=1 : EPG_NB_ELEC
    ligne = fgetl(fid);
    elec = [elec,sscanf(ligne,'%i',22)];
  end

  % Plus bas ds le fichier se trouvent le nom des rgions.
  % Lecture du nom des rgions
  % Place le curseur de fichier dans la partie PROMPTS
  carac = fscanf(fid,'%c',1);
  while(~strcmp(carac,'*'))
    carac = fscanf(fid,'%c',1);
  end
  fseek(fid,21,0);

  % Pour chaque rgion, lit le nom
  for n=1 : 18
    fseek(fid,10,0);
    nom = fscanf(fid,'%s',1); 
    EPG_NOM_REG(n,1:length(nom)) = nom;

    % Va a la ligne suivante    
    carac = fscanf(fid,'%c',1);
    while(~strcmp(carac,'T'))
      carac = fscanf(fid,'%c',1);
    end
  end

  %=====================
  % Fermeture du fichier
  %=====================

  fclose(fid);

  % La matrice elec contient les donnes sous la forme :
  % n electrode : 1 .. 96
  % n ligne :     0 .. 37
  % n colonne :   8 .. 40 (dpend du palais du locuteur)
  % n channel :   1 .. 96 
  % n region

  % On garde les lignes et les colonnes 
  % connaitre la position de chaque electrode sur le palais
  EPG_POS_ELEC = elec(2:3,:);
  
  % On garde aussi la correspondance entre les canaux et les electrodes
  % pour pouvoir lire les fichiers de donnees .nsp
  for n=1 : EPG_NB_ELEC
    EPG_CHANNEL(elec(4,n)) = n;
  end
  
  % Et enfin les rgions pour les calculs de taux de contact par rgion
  EPG_REGIONS = elec(5:22,:);
end
