% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fonction : MD_align('dir', 'rootfilename')
% 
% MD_align('D:\Hlne\Projets\ACI_DImperio\DonneesFrench\MD_EMA\renamed\', '042-10-l-n-1-m-2-2-md')
%
% Source : Matlab
% Auteurs : C. Savariaux & H. Loevenbruck
% Date de cration : 1 mars 2002
% Dernire modification : 11 mars 2004
%          
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function MD_align(dir, rootfilename)

% Lancement de l'application
% ---------------------------

trap;

% Initialisation des variables globales
% --------------------------------------

ACOU_FECH = 20000;     % Freq. d'chantillonnage du signal acoustique
EMA_FECH = 500;        % Freq. d'chantillonnage du signal EMA
CHEBY_FREQ_COUP = 20;    % Freq de coupure du Pbas de Chebychev
% si CHEBY_FREQ_COUP=0 pas de filtrage (des donnes ou de la vitesse)
REP_SEUIL = 10;     % A modifier si le calcul des maxima ou minima est mauvais

% Changement des noms par dfaut des niveaux d'tiquette 
NIV_ETIQ = 5;
TYPE_ETIQ(:,:)='';
TYPE_ETIQ(1,1:length('word'))=sprintf('%s','word');
TYPE_ETIQ(2,1:length('syl'))='syl';
TYPE_ETIQ(3,1:length('seg'))='seg';
TYPE_ETIQ(4,1:length('tone'))='tone';
TYPE_ETIQ(5,1:length('misc'))='misc';

% Changement des couleurs par dfaut des niveaux d'tiquette 
% Les couleurs pseudo-rouge sont  proscrire pour ne pas confondre avec le
% curseur
% Pour rendre presque invisible des tiquettes, il suffit de les coder en noir, 
% soit par exemple : COULEUR_ETIQ(1,:) = [0 0 0];  

COULEUR_ETIQ(1,:) = [1 1 .45];   % sort of yellow
COULEUR_ETIQ(2,:) = [0 0 .95];   % sort of blue
COULEUR_ETIQ(3,:) = [.45 .45 .45];   % sort of grey
COULEUR_ETIQ(4,:) = [1 .45 1];   % sort of magenta
COULEUR_ETIQ(5,:) = [1 .45 0];   % sort of orange

% Dfinition du nom des bobines
EMA_BOB1 = 'DORS';     
EMA_BOB2 = 'NOSE';
EMA_BOB3 = 'REF';
EMA_BOB4 = 'BACK';
EMA_BOB5 = '';
EMA_BOB6 = 'APEX';
EMA_BOB7 = 'MID';    
EMA_BOB8 = 'UL';
EMA_BOB9 = 'LL';
EMA_BOB10 = 'JAW';     

% Construction des noms de fichier
% --------------------------------

nom_fich_ema = [dir 'mat\' rootfilename '.mat']
nom_fich_wav = [dir 'wav\' rootfilename '.wav']
nom_fich_f0 = [dir 'F0\' rootfilename '.F0']
nom_fich_etiq = [dir 'TextGrid\' rootfilename '.TextGrid']

% Chargement du fichier binaire de donnes articulatoires
% et des donnes acoustiques
% NOTE :  bien faire avant d'ouvrir les fenetres
acou_ouv(nom_fich_wav, 'WAV');
ema_ouv_mat(nom_fich_ema);

% Ouverture de la fenetre principale avec 7 lignes et 2 colonnes
% --------------------------------------------------------------

fenetre(2,7,[20 80],[1000 650],'Fenetre principale');

% Traitement acoustique
%----------------------

% Visualisation du signal acoustique
acou_signal;
mes_axes = axis;
graphe_suivant;

% Visualisation du spectrogramme
%ACOU_ORD_FFT = 512;
%ACOU_LONG_FEN = 128;
%ACOU_FEN_TMP = hanning(ACOU_LONG_FEN);  % Vecteur colonne
%ACOU_OVER_FEN = 64;
%acou_spectro;
%graphe_suivant;

% Visualisation de la F0
acou_affich_f0(nom_fich_f0,'ASC2',100);
modif_echelle(mes_axes(1),mes_axes(2),  180, 300);
graphe_suivant;

% Visualisation de l'intensit
%acou_intensite;
%graphe_suivant;

% Affichage des trajectoires, vitesses et acclrations de quelques bobines
% ---------------------------------------------------------------------------

% Mise en forme des donnes EMA
ema_traitement;

% TRAJ TONGUE APEX X 
ema_traj(EMA_X6,[EMA_BOB6,'-X']);
graphe_suivant;

% VELOCITY TONGUE APEX X 
ema_vit(EMA_X6,[EMA_BOB6,'-X']);
graphe_suivant;

% TRAJ TONGUE APEX Y 
ema_traj(EMA_Y6,[EMA_BOB6,'-Y']);
graphe_suivant;

% VELOCITY TONGUE APEX Y
ema_vit(EMA_Y6,[EMA_BOB6,'-Y']);
graphe_suivant;

% EUCLIDIAN DISTANCE BETWEEN UPPER and LOWER LIP PELLETS
LIP_HEIGHT = sqrt( (EMA_Y8 - EMA_Y9) .*(EMA_Y8 - EMA_Y9) +  (EMA_X8 - EMA_X9) .*(EMA_X8 - EMA_X9) );
ema_traj(LIP_HEIGHT,['LH']);
graphe_suivant;

% VELOCITY LIP HEIGHT
ema_vit(LIP_HEIGHT,['LH']);
graphe_suivant;

% UPPER LIP PROTRUSION
% The origin of the X axis is inside the mouth (bite plane)
% X values increase going inside the mouth and decrease going outside.

LIP_PROTRUSION = - EMA_X8;
ema_traj(LIP_PROTRUSION,['LP']);
graphe_suivant;

% VELOCITY UPPER LIP PROTRUSION
ema_vit(LIP_PROTRUSION,['LP']);
graphe_suivant;

% TRAJ TONGUE MIDDLE Y
ema_traj(EMA_Y7,[EMA_BOB7,'-Y']);
graphe_suivant;

% VELOCITY TONGUE MIDDLE Y
ema_vit(EMA_Y7,[EMA_BOB7,'-Y']);
graphe_suivant;

% TRAJ JAW Y
ema_traj(EMA_Y10,[EMA_BOB10,'-Y']);
graphe_suivant;

% VELOCITY JAW Y
ema_vit(EMA_Y10,[EMA_BOB10,'-Y']);
graphe_suivant;

% Affichage des tiquettes
% ------------------------

ouv_etiq(nom_fich_etiq)

% Zoom on the target word
% + cursor at Low elbow
% ------------------------

zoom_in(0.75, 1.9);
curseur(0.9543);
