% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : exemple_tac.m
% Source : Matlab
% Auteur : H. Loevenbruck
% Date de cration : 18.09.02
% Date de dernire modification : 18.09.02
% Contenu : Fichier d'exemple pour les fichiers de donnes 
%           de paramtres de lvres issus de TACLE (.tac)
%
% NOTE : Pour utiliser cet exemple, il est necessaire de charger en local
% les fichiers .wav et .tac ET de modifier les paths aux lignes 22
% (acou_ouv) et 43 (tac_ouv).
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Lancement de l'application
trap;

% Initialisation des variables globales
ACOU_FECH = 22050;   % Freq. d'chantillonnage du signal acoustique

% Chargement du fichier acoustique binaire
acou_ouv('Q:\matlab\trap\trap_v5\exemples\data\l_sik_skult05.wav', 'WAV') 

% Ouverture des fenetres principales et synchrones
fenetre(1,7,[20 90],[800 650],'Fenetre principale');

% Visualisation du signal acoustique
acou_signal;
titre_signal = sprintf('sik skultere');
titre(titre_signal);

% Nombre et nom des paramtres souhaits
MES_NB = 4;
MES_NOM(1,1:length('A')) = 'A';
MES_NOM(2,1:length('B')) = 'B';
MES_NOM(3,1:length('S')) = 'S';
MES_NOM(4,1:length('P1')) = 'P1';

% Frquence d'chantillonage des donnes TACLE
MES_FECH = 50;

% Ouverture du fichier TACLE 
tac_ouv('Q:\matlab\trap\trap_v5\exemples\data\l_sik_skult05.tac');

% Trac de P1
graphe_suivant;
trace_graphe(MES_DATA(4,:),MES_TPS,'P1', '-', [ 1 1 0]);

% on filtre P1 et on trace
CHEBY_FREQ_COUP = 6;
[P1_filt6] = filtre_cheby(MES_DATA(4,:),MES_FECH, CHEBY_FREQ_COUP);
graphe_suivant;
trace_graphe(P1_filt6,MES_TPS,'P1-filt6', '-', [ 1 1 0]);

% on filtre P1 et on trace
CHEBY_FREQ_COUP = 8;
[P1_filt8] = filtre_cheby(MES_DATA(4,:),MES_FECH, CHEBY_FREQ_COUP);
graphe_suivant;
trace_graphe(P1_filt8,MES_TPS,'P1-filt8', '-', [ 1 1 0]);

% on filtre P1 et on trace
CHEBY_FREQ_COUP = 10;
[P1_filt10] = filtre_cheby(MES_DATA(4,:),MES_FECH, CHEBY_FREQ_COUP);
graphe_suivant;
trace_graphe(P1_filt10,MES_TPS,'P1-filt10', '-', [ 1 1 0]);

P1 =MES_DATA(4,:);

% Calcul de la vitesse de P1 filtr
%[vit_P1] =  calc_vit(MES_DATA(4,:),MES_FECH);
CHEBY_FREQ_COUP = 20;
[vit_P1] =  calc_vit(P1_filt6,MES_FECH);

% on la trace
graphe_suivant;
trace_graphe(vit_P1,MES_TPS,'vit-P1', '-', [ 1 1 0]);

% Acceleration de P1 filtr
[acc_P1] = calc_acc_ord3(P1_filt6,MES_FECH);
graphe_suivant;
trace_graphe(acc_P1,MES_TPS,'acc-P1', '-', [ 1 1 0]);


%[acc_A] =  calc_vit_cs(vit_A_filt,MES_FECH);
%graphe_suivant;
%trace_graphe(acc_A,MES_TPS,'acc-A', '-', [ 1 1 0]);
