% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : filtre_subplot.m
% Source : Matlab
% Auteur : LN et CS
% Date : 21.01.04
% Contenu : Filtre le signal contenu dans le subplot actif
%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function filtre_subplot(type_filtre, freq_coup, nb_interp)


% Recherche de tous les signaux et tiquettes contenus ds le subplot courant
gr_lines = findobj(gca,'Type','line');

nb_signaux = 0;
for ind_gr = 1 : length(gr_lines)
   % On ne s'intresse qu'aux signaux et on vacue les tiquettes (de lenght 2)
      if (length(get(gr_lines(ind_gr), 'xdata')) > 2) 
         nb_signaux = nb_signaux +1;
         signal = ind_gr;
      end
end

if (nb_signaux < 1)
   errordlg(' Impossible de filtrer : Il n''y a pas de signal temporel !','Erreur','on');
   return;
elseif (nb_signaux > 1)
   errordlg(' Impossible de filtrer : des graphes sont superposs !','Erreur','on');
   return;
else
   donnees_temporelles = get(gr_lines(signal), 'xdata');
   donnees = get(gr_lines(signal), 'ydata');
   BorneSupX = donnees_temporelles(length(donnees_temporelles));    
   FrequenceEch = (length(donnees_temporelles) -1)/BorneSupX;
   % Application du filtre de type 'type_filtre' (chebyshev, remez ou spline) et de
   % frquence de coupure 'freq_coup'
   if strcmp(type_filtre, 'Chebyshev')
        signal_filt = filtre_cheby(donnees, FrequenceEch, freq_coup);
        nom_f = '-Cheby';
   elseif strcmp(type_filtre, 'Spline')
        [signal_filt, donnees_temporelles] = filtre_spline(donnees, FrequenceEch, nb_interp);
        nom_f = '-Spline';
   elseif strcmp(type_filtre, 'Remez')
       signal_filt = filtre_remez(donnees', FrequenceEch);
       nom_f = '-Remez';
   end
  
   % re-affiche le titre du subplot en green
   texte = findobj(gca,'Type','text','Color',[0 1 0]); %recherche texte green   

   if ~isempty(texte)
          nom = get(texte,'string');
          nom = [nom nom_f];
   end
   trace_graphe(signal_filt,donnees_temporelles, nom , '-', [ 1 1 0]);
end
zoom_out;
