% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : minmaxppz.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 01.04.2000
% Contenu : Repre les minima, les maxima, les 
%           passages par zro ou la moyenne entre 2 points
%           sur un signal articulatoire.
%
% Modifi par CS le 02/04/04 :
%   rajout des fonctions de recherche du min et max absolu
%   rajout de la fonction de recherche de 90% du max et 10% du min
% Modifi par CS le 05/07/06 :
%       Ajout des fichiers EGG (DCF)
% Modifi par CS le 14/02/17 :
%       ajout du mode 'fixe' qui calcule entre 2 points rentrs en paramtres [pos1, pos2]
% Modifi par CS le 15/02/18 :
%       ajout du mode reperage du tps  20% du max rep_20pc_max, uniquement
%       sur signaux EMA
%
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function minmaxppz(min_ou_max, type_donnees, click, pos1, pos2)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 3
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : minmaxppz(min_ou_max, type_donnees, click)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global NUM_FEN EMA_TPS EPG_TPS MES_TPS EMA_FECH EPG_FECH MES_FECH FE_ACTIF TPS_EVA_ACTIF
global EGG_TPS EGG_FECH

if (min_ou_max < 1 || min_ou_max > 8)
   chaine_erreur = sprintf(' Attention ! \n\n Veuillez prciser le type du reprage demand :\n 1 pour min loc,\n 2 pour max loc, \n 6 pour min abs,\n 7 pour max abs,\n 3 pour passage par zro,\n 4 pour moyenne,\n 5 pour 10-90% du min max\n');
   errordlg(chaine_erreur,'Erreur','on');
   return;
end

if ~strcmp(type_donnees, 'EMA') && ~strcmp(type_donnees, 'EPG') && ~strcmp(type_donnees, 'MES') && ~strcmp(type_donnees, 'EVA') && ~strcmp(type_donnees, 'EGG')
   chaine_erreur = sprintf(' Attention ! \n\n Veuillez prciser le type du fichier, parmi :\n ''EMA'', ''EPG'', ''EVA'' , ''EGG'' et ''MES''\n');
   errordlg(chaine_erreur,'Erreur','on');
   return;
end

if ~strcmp(click, 'manuel') && ~strcmp(click, 'auto') && ~strcmp(click, 'fixe')
   chaine_erreur = sprintf(' Attention ! \n\n Veuillez prciser le mode, parmi :\n ''auto'', ''fixe'' ou ''manuel''\n');
   errordlg(chaine_erreur,'Erreur','on');
   return;
end

if strcmp(type_donnees, 'EMA')
   tps = EMA_TPS;
   fech = EMA_FECH;
elseif strcmp(type_donnees, 'EPG')
   tps = EPG_TPS;
   fech = EPG_FECH;
elseif strcmp(type_donnees, 'MES')
   tps = MES_TPS;
   fech = MES_FECH;
elseif strcmp(type_donnees, 'EVA')
   tps = TPS_EVA_ACTIF;
   fech = FE_ACTIF;
elseif strcmp(type_donnees, 'EGG')
   tps = EGG_TPS;
   fech = EGG_FECH;
else
   tps = MES_TPS;
   fech = MES_FECH;
end

if isempty(tps)
  if min_ou_max == 1 || min_ou_max == 6
     chaine_erreur = sprintf(' Attention ! \n\n Aucun fichier de type %s n'' a t charg.\n Il est impossible de reprer les minima.', type_donnees);
  elseif min_ou_max == 2 || min_ou_max == 7
     chaine_erreur = sprintf(' Attention ! \n\n Aucun fichier de type %s n'' a t charg.\n Il est impossible de reprer les maxima.', type_donnees);
  elseif min_ou_max == 3
     chaine_erreur = sprintf(' Attention ! \n\n Aucun fichier de type %s n'' a t charg.\n Il est impossible de reprer les passages par zro.', type_donnees); 
  elseif min_ou_max == 4
     chaine_erreur = sprintf(' Attention ! \n\n Aucun fichier de type %s n'' a t charg.\n Il est impossible de reprer la moyenne.', type_donnees);
  elseif min_ou_max == 5
     chaine_erreur = sprintf(' Attention ! \n\n Aucun fichier de type %s n'' a t charg.\n Il est impossible de reprer les valeurs.', type_donnees);
  else
     chaine_erreur = sprintf(' Attention ! \n\n Le type du reprage (min, max, passage par zro ou moyenne) n''a pas t prcis.\n');
  end
  errordlg(chaine_erreur,'Erreur','on');
  return;
end

if NUM_FEN == 0
  errordlg(' Veuillez ouvrir une fenetre principale','Erreur','on');
  return;
end

figure(NUM_FEN);

if strcmp(click, 'manuel')
    % Attend que l'utilisateur slectionne les 2 points entre lesquels
    % il faut chercher les minima
    [pos_x,pos_y, bouton] = ginput(1);
    %     [pos_x,pos_y,bouton] = ginputc(1,'Color', COULEUR_POINTEUR);
elseif strcmp(click, 'fixe')
    bouton = 2;
else
    bouton = 3;
end

% Rcupre les donnes du signal
%-------------------------------
% Recherche de tous les signaux et tiquettes 
% contenus ds l'axe courant 
%--------------------------------------------
recherche = 0;
gr_lines = findobj(gca,'Type','line'); 

if isempty(gr_lines)
  errordlg(' Impossible de rechercher min/max/passage par zro/moy : ce signal n''est pas temporel !','Erreur','on');
  return;
else
  [~,ind_gr_lines_tries] = sort(gr_lines);

  for ind_gr = 1 : length(gr_lines)
       % On ne s'intresse qu'aux signaux articulatoires 
       % i.e. on ne traite pas les signaux acoustiques ni les tiquettes.
       % S'il y a plusieurs signaux articulatoires superposs
       % le reprage des min-max-ppz-moy se fera sur le dernier trac.

       val_y = get(gr_lines(ind_gr_lines_tries(ind_gr)),'Ydata');
       % Evacuation des tiquettes ou repres-croix
       if length(val_y) > 2
         recherche = 1;
         % Evacuation des signaux non-articulatoires
         if length(val_y) ~= length(tps)
            chaine_erreur = '';
            if min_ou_max == 1 || min_ou_max == 6
               chaine_erreur = sprintf(' Attention ! \n\n Le reprage des minima doit se faire sur des donnes de type %s.\n\n Veuillez slectionner un autre graphe.', type_donnees);
            elseif min_ou_max == 2 || min_ou_max == 7
               chaine_erreur = sprintf(' Attention ! \n\n Le reprage des maxima doit se faire sur des donnes de type %s.\n\n Veuillez slectionner un autre graphe.', type_donnees);
            elseif min_ou_max == 3
               chaine_erreur = sprintf(' Attention ! \n\n Le reprage des passages par zro doit se faire sur des donnes de type %s.\n\n Veuillez slectionner un autre graphe.', type_donnees);    
            elseif min_ou_max == 4
               chaine_erreur = sprintf(' Attention ! \n\n Le reprage de la moyenne doit se faire sur des donnes de type %s.\n\n Veuillez slectionner un autre graphe.', type_donnees);
            elseif min_ou_max == 5
               chaine_erreur = sprintf(' Attention ! \n\n Le reprage des maxima-90 doit se faire sur des donnes de type %s.\n\n Veuillez slectionner un autre graphe.', type_donnees);
            else
               chaine_erreur = sprintf(' Attention ! \n\n Le type du reprage (min, max, passage par zro ou moyenne) n''a pas t prcis.\n');
            end
            errordlg(chaine_erreur, 'Erreur', 'on');
            return;
         end
         % Teste si l'on effectue une recherche entre 2 pts ou sur tout le signal
         if bouton == 1
             % Attend la deuxime coordonne
             [pos_x(2),pos_y(2)] = ginput(1);
             %              [pos_x(2),pos_y(2)] = ginputc(1,'Color', COULEUR_POINTEUR);
             
             % Recherche les donnes du signal comprises entre ces 2 points
             i_deb = fix(pos_x(1)*fech+1);
             i_fin = fix(pos_x(2)*fech+1);
             if i_fin > length(val_y)
                 i_fin = length(val_y);
             end
             signal = val_y(i_deb : i_fin);
             temps = tps(i_deb : i_fin);             
         elseif bouton == 2
             % On convertit les temps en echantillon
             i_deb = fix(pos1*fech+1);
             i_fin = fix(pos2*fech+1);
             if i_fin > length(val_y)
                 i_fin = length(val_y);
             end
             signal = val_y(i_deb : i_fin);
             temps = tps(i_deb : i_fin);
         else % bouton = 3
             % Recherche sur tout le signal
             signal = val_y;
             temps = tps;
         end
         
       end
  end
end

% Effectue la recherche du min ou du max
if recherche == 1
  if min_ou_max == 1
    rep_min(signal,fech,temps);
  elseif min_ou_max == 2
    rep_max(signal,fech,temps);
  elseif min_ou_max == 3
    rep_ppz(signal,fech,temps);
  elseif min_ou_max == 4
    rep_moy(signal, fech,temps);
  elseif min_ou_max == 5
    rep_max_90dechute(signal, fech,temps);
  elseif min_ou_max == 6
    rep_min_abs(signal, fech,temps);
  elseif min_ou_max == 7
    rep_max_abs(signal, fech,temps);
  elseif min_ou_max == 8
    rep_20pc_max(signal, fech, temps); % fonction permettant de trouver le temps  20% du max
  end
end

recherche = 0;
