% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : ouv_etiq.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 21.01.03
%
% Modifi par CS : 16/10/19, suppression format ISIS
%   + ajout du niveau_etiq  spcifier en entre de la fonction
%
% Contenu : Ouverture du fichier contenant 
%           les tiquettes + affichage.
% Les formats des fichier d'tiquettes possibles
% sont PRAAT, TRAP.
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function ouv_etiq(nomfic, niveau_etiq)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 1
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : ouv_etiq(nomfic)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global COULEUR_ETIQ NIV_ETIQ TYPE_ETIQ

fid = fopen(nomfic, 'r');
if fid == -1   
  errordlg([' Fichier ',nomfic,' introuvable'],'Rsultat','on');
  return;
else
  % Sauvegarde de l'ancien nombre de niveaux d'tiquetage
  old_niv_etiq = NIV_ETIQ ;

  % On lit la premire ligne pour connaitre le nombre de niveaux 
  % et les noms des tiquettes
  line = fgetl(fid);

  
  % Cas d'un fichier seg cr sous PRAAT
  %------------------------------------
  if strcmp(line(1:24), 'File type = "ooTextFile"')
      buf =  fscanf(fid,'%s',1);
      while ~strcmp(buf, 'size')
          buf =  fscanf(fid,'%s',1);
      end
      buf =  fscanf(fid,'%s',1); % lit " = "
      
      if nargin == 2
          NIV_ETIQ = niveau_etiq;
      else
          NIV_ETIQ  =  fscanf(fid,'%d',1); % lit le nombre de tiers (niveaux) PRAAT
      end
      
      if isempty(NIV_ETIQ)
          errordlg(' Le format du fichier d''tiquettes est incorrect !', 'Erreur', 'On');
          fclose(fid);
          return;
      end
      
      % initialisation de certaines variables globales si necessaires
      if NIV_ETIQ > old_niv_etiq
          for i = old_niv_etiq+1:NIV_ETIQ
              COULEUR_ETIQ(i,:) =  (1 - 1/(4*i)) *[COULEUR_ETIQ(1,1) COULEUR_ETIQ(1,2) COULEUR_ETIQ(1,3)];
              nom_niveau = sprintf('Niveau %d', i);
              TYPE_ETIQ(i,1:length(nom_niveau)) = nom_niveau;
          end
     end
     
     buf =  fscanf(fid,'%s',1);
     
     % boucle sur le nombre de niveaux
     while ~strcmp(buf, 'item')          % lit le premier item []: 
            buf =  fscanf(fid,'%s',1);
     end
  
     for niveau = 1:NIV_ETIQ
         buf =  fscanf(fid,'%s',1);
         
         while ((~strcmp(buf, 'intervals:')) && (~strcmp(buf, 'points:')) )
             buf =  fscanf(fid,'%s',1);
        end 
        type_ligne = buf;
        
         while ~strcmp(buf, 'size')  
            buf =  fscanf(fid,'%s',1); 
         end
         buf =  fscanf(fid,'%s',1); % lit " = "
	     nombre_etiq  =  fscanf(fid,'%d',1); % lit le nombre d'tiquettes pour ce niveau
         
         
         %boucle sur le nombre d'tiquettes
         if strcmp(type_ligne, 'intervals:')
             
             for label = 1:(nombre_etiq-1)
                 while ~strcmp(buf, 'xmax')  
                    buf =  fscanf(fid,'%s',1); 
                 end
                 buf =  fscanf(fid,'%s',1); % lit " = "
	             pos  =  fscanf(fid,'%f',1); % lit la position de l'tiquette
                 buf =  fscanf(fid,'%s',1); % lit "text"
                 buf =  fscanf(fid,'%s',1); % lit " = "
	             texte_guillemet  =  fscanf(fid,'%s',1); % lit le texte de l'tiquette
                 texte = texte_guillemet(2:(length(texte_guillemet)- 1)); %enlve les guillemets
                 marquer(pos,texte,niveau);
             end
         elseif strcmp(type_ligne, 'points:')
             
             for label = 1:(nombre_etiq-1)
                 while ~strcmp(buf, 'number')
                     buf =  fscanf(fid,'%s',1);
                 end
                 buf =  fscanf(fid,'%s',1); % lit " = "
                 pos  =  fscanf(fid,'%f',1); % lit la position de l'tiquette
                 buf =  fscanf(fid,'%s',1); % lit "mark"
                 buf =  fscanf(fid,'%s',1); % lit " = "
                 texte_guillemet  =  fscanf(fid,'%s',1); % lit le texte de l'tiquette
                 texte = texte_guillemet(2:(length(texte_guillemet)- 1)); %enlve les guillemets
                 marquer(pos,texte,niveau);
             end
         else
             errordlg(' Ce type de fichier d''tiquettes est inconnu.', 'Erreur', 'on');
             fclose(fid);
             return;
         end
         
     end
     
  
  % Cas d'un fichier seg cr sous TRAP
  %------------------------------------
  elseif strcmp(line(1:4), 'TRAP')
     buf =  fscanf(fid,'%s',1);
     if ~strcmp(buf, 'signal')
        errordlg(' Le format du fichier d''tiquettes est incorrect !', 'Erreur', 'On');
	fclose(fid);
	return;
     end

     while ~strcmp(buf, 'color')
        buf =  fscanf(fid,'%s',1);
     end
     buf = fscanf(fid,'%s',1); %lit le ':'
     if ~strcmp(buf, ':')
        errordlg(' Le format du fichier d''tiquettes est incorrect !', 'Erreur', 'On');
	fclose(fid);
	return;
     end
     for i = 1 : 3
        COULEUR_ETIQ(1,i) = fscanf(fid,'%f',1);
        if isempty(COULEUR_ETIQ(1,i))
             errordlg(' Le format du fichier d''tiquettes est incorrect !', 'Erreur', 'On');
	     fclose(fid);
	     return;
        end
     end
 
     buf = fscanf(fid,'%s',1); %lit le 'nfields'
     if ~strcmp(buf, 'nfields')
        errordlg(' Le format du fichier d''tiquettes est incorrect !', 'Erreur', 'On');
	fclose(fid);
	return;
     end
     buf = fscanf(fid,'%s',1); %lit le ':'
     if ~strcmp(buf, ':')
        errordlg(' Le format du fichier d''tiquettes est incorrect !', 'Erreur', 'On');
	fclose(fid);
	return;
     end
     NIV_ETIQ = fscanf(fid,'%d',1);
     if isempty(NIV_ETIQ)
        errordlg(' Le format du fichier d''tiquettes est incorrect !', 'Erreur', 'On');
	fclose(fid);
	return;
     end

     % initialisation de certaines variables globales si necessaires
     if NIV_ETIQ > old_niv_etiq
         for i = old_niv_etiq+1:NIV_ETIQ
            COULEUR_ETIQ(i,:) =  (1 - 1/(4*i)) *[COULEUR_ETIQ(1,1) COULEUR_ETIQ(1,2) COULEUR_ETIQ(1,3)];
            nom_niveau = sprintf('Niveau %d', i);
            TYPE_ETIQ(i,1:length(nom_niveau)) = nom_niveau;
         end
     end

     line = fgetl(fid); % return character
     if ~strcmp(line ,'')
        errordlg(' Le format du fichier d''tiquettes est incorrect !', 'Erreur', 'On');
	fclose(fid);
	return;
     end
     line = fgetl(fid); % lit ligne vide
     if ~strcmp(line ,'')
        errordlg(' Le format du fichier d''tiquettes est incorrect !', 'Erreur', 'On');
	fclose(fid);
	return;
     end
     line = fgetl(fid);
     if strcmp(line ,'') | line==-1
        errordlg(' Le format du fichier d''tiquettes est incorrect !', 'Erreur', 'On');
	fclose(fid);
	return;
     end

     while line~=-1
        [pos, count,errmsg, nextind]  = sscanf(line,'%f %d',2);
        nom = sscanf(line(nextind:length(line)),'%s',1);
        if ~isempty(pos)  % Traite le cas des lignes vides laisses  la fin.
           marquer(pos(1),nom,pos(2));
        end
        line = fgetl(fid);
     end

  % Cas d'un fichier de format inconnu
  %------------------------------------
  else
     errordlg(' Ce type de fichier d''tiquettes est inconnu.', 'Erreur', 'on'); 
     fclose(fid);
     return;
  end
  
  fclose(fid);
end
