% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : rep_max.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifie par H. Loevenbruck 27.10.99
% Contenu : Repre les maxima d'un signal
% Ils seront marqus par des curseurs de couleur 
% orang.
% Modifi par CS et LN le 18.03.03 : 
%  calc_vit : modif vecteur ligne en colonne
% Modifi par CS et LN le 01.04.04 : 
%   amelioration de la recherche des maxima avec tests des proches voisin
% Modifi par CS le 04.01.16 : 
%   amelioration de la recherche des minima suppression de la notion de
%   seuil
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function rep_max(sig,fech,tps)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 3
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : rep_max(signal, Fe, tps)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

% global REP_SEUIL ACOU_TYP_FIC COULEUR_MAX
global ACOU_TYP_FIC COULEUR_MAX

%initialisation 
pic_pal = [];

% Calcule la derive du signal
% modif Cs et LN
der_sig = calc_vit(sig,fech);


% Recherche des passages par zro de la drivee
% En fait on prend toutes les valeurs dont la valeur absolue est
% infrieure au seuil.
borne_sup = max(abs(der_sig));
borne_inf = min(abs(der_sig));
% seuil = (borne_sup - borne_inf)/REP_SEUIL;
% ind_z = find(abs(der_sig) <= seuil);
% Modif CS
ind_z = 1:length(der_sig);

vmax = [];

% Dtermination des maximas
% On commence  2 car la premire valeur de la vitesse est toujours nulle
for i = 2 : length(ind_z)
  ind_s = ind_z(i);
  if ind_s < length(der_sig)
    % Si la derive du signal  l'indice prcdent est ngative et
    % qu'elle est positive  l'indice suivant, alors l'indice courant
    % correspond  un maximum du signal
    if ind_s > 1
      if (der_sig(ind_s-1) > 0) && (der_sig(ind_s) <= 0)
        % on teste les proches voisins 
        if sig(ind_s-1) > sig(ind_s)
	        % on prend l'indice precedent 
	        vmax = [vmax, ind_s-1];
        else
            % on garde l'indice courant
            vmax = [vmax, ind_s];
        end
      end
    end
  end
end


% Cas d'un signal EPG
if strcmp(ACOU_TYP_FIC,'EPG')
  % Dtermination des paliers
  plateau = find(der_sig == 0);
  k=2;
  while k < length(plateau)
    clear palier;
    palier = [];
    % On est dans un plateau tant que les indices se suivent
    while k < length(plateau)-1
      if plateau(k)+1 == plateau(k+1)
	    palier = [palier,plateau(k)];
	    k = k+1;
      else  
	    return;
      end
    end
    % On marque le premier indice de chaque plateau
    if ~isempty(palier)
      palier = [palier,plateau(k)];
      % On a un plateau min lorsque la pente est positive avant le
      % plateau et ngative apres
      if (der_sig(palier(1)-1) > 0) && (der_sig(palier(length(palier))+1) < 0)
	    pic_pal = [pic_pal,palier(1)];
      end
    else
      k = k+1;
    end
  end
end

% Ajoute le marquage des plateaux
vmax = [vmax,pic_pal];
max_trouve = sig(vmax);

if ~isempty(vmax)
    % Affichage
    % Attention, ne pas modifier le code de couleur, 
    % sinon l'effacage des min-max ne marchera plus.
    % cf. eff_minmaxppz.m
    hsub = subplot(gca);
    limY = get(hsub,'Ylim');
    hold on;
    for n=1 : length(vmax)
        line([tps(vmax(n)) tps(vmax(n))],limY,'Color', COULEUR_MAX); %sort of orange
    end
    hold off;
else
    warndlg('Pas de Maxima locaux trouv', 'Attention');
end
