% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : rep_min.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 21.10.99
% Contenu : Repre les minima d'un signal
% Ils seront marqus par des curseurs de couleur
% COULEUR_MIN.
% Modifi par CS et LN le 18.03.03 :
%  calc_vit : modif vecteur ligne en colonne
% Modifi par CS et LN le 01.04.04 :
%   amelioration de la recherche des minima avec tests des proches voisin
% Modifi par CS le 04.01.16 :
%   amelioration de la recherche des minima suppression de la notion de
%   seuil
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function rep_min(sig,fech,tps)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 3
    chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : rep_min(signal, Fe, tps)');
    errordlg(chaine_erreur, 'Erreur', 'on');
    return;
end

% global REP_SEUIL ACOU_TYP_FIC COULEUR_MIN
global ACOU_TYP_FIC COULEUR_MIN

%initialisation
pic_pal = [];

% Calcule la drive du signal
% modif Cs et LN
der_sig = calc_vit(sig,fech);

% Recherche des passages par zro de la drive
% En fait on prend toutes les valeurs dont la valeur absolue est
% infrieure au seuil.
borne_sup = max(abs(der_sig));
borne_inf = min(abs(der_sig));
% seuil = (borne_sup - borne_inf)/REP_SEUIL;
% ind_z = find(abs(der_sig) <= seuil);
% Modif CS
ind_z = 1:length(der_sig);

min_trouve = [];

% Dtermination des minimas
% On commence  2 car la premire valeur de la vitesse est toujours nulle
for i=2 : length(ind_z)
    ind_s = ind_z(i);
    if ind_s < length(der_sig)
        if ind_s > 1
            % Si la derive du signal  l'indice prcdent est ngative et
            % qu'elle est positive  l'indice suivant, alors l'indice courant
            % correspond  un minimum du signal
            if ((der_sig(ind_s-1) < 0) && (der_sig(ind_s) >= 0))
                % on teste les proches voisins
                if (sig(ind_s-1) <= sig(ind_s))
                    % on prend l'indice precedent
                    min_trouve = [min_trouve,ind_s-1];
                else
                    % on garde l'indice courant
                    min_trouve = [min_trouve,ind_s];
                end
            end
        end
    end
end

% Cas d'un signal EPG
if strcmp(ACOU_TYP_FIC,'EPG')
    % Dtermination des paliers
    plateau = find(der_sig == 0);
    k=2;
    while k < length(plateau)
        clear palier;
        palier = [];
        % On est dans un plateau tant que les indices se suivent
        while k < length(plateau)-1
            if plateau(k)+1 == plateau(k+1)
                palier = [palier,plateau(k)];
                k = k+1;
            else
                return;
            end
        end
        % On marque le premier indice de chaque plateau
        if ~isempty(palier)
            palier = [palier,plateau(k)];
            % On a un plateau min lorsque la pente est ngative avant le
            % plateau et positive aprs
            if (der_sig(palier(1)-1) < 0) && (der_sig(palier(length(palier))+1) > 0)
                pic_pal = [pic_pal,palier(1)];
            end
        else
            k = k+1;
        end
    end
end

% Ajoute le marquage des plateaux
min_trouve = [min_trouve,pic_pal];
mini_trouve = sig(min_trouve);

if ~isempty(min_trouve)
    %Affichage des minima
    hsub = subplot(gca);
    limY = get(hsub,'Ylim');
    hold on;
    for n=1 : length(min_trouve)
        line([tps(min_trouve(n)) tps(min_trouve(n))],limY,'Color', COULEUR_MIN); %sort of cyan
        %mini_trouve = sig(min_trouve(n))
    end
    hold off;
else
    warndlg('Pas de Minima locaux trouv', 'Attention');
end


